@@ -22,18 +22,8 @@ class Population:
             string += "\t{},\n".format(individual.__str__())
         return string
 
-    def gen_population_from_table(self, table):
-        for parameters in table:
-            individual = Individual(parameters)
-            self.individuals.append(individual)
+    def __eq__(self, other):
+        if not isinstance(other, Population):
+            return NotImplemented
 
-    def to_list(self, population_number):
-        table = []
-        for individual in self.individuals:
-            params = individual.to_list()
-            params.insert(0, self.individuals.index(individual) + 1)
-            # population index
-            params.insert(1, population_number)
-            table.append(params)
-
-        return table
+        return self.individuals == other.individuals and self.archives == other.archives and self.pareto_vectors == other.pareto_vectors and self.pareto_costs == other.pareto_costs
\ No newline at end of file
